Coverage report

File | function | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
lice2/__init__.py | (no function) | 3 | 0 | 0 | 100%
lice2/api/__init__.py | (no function) | 2 | 0 | 0 | 100%
lice2/api/api.py | Lice.__init__ | 9 | 0 | 0 | 100%
lice2/api/api.py | Lice.get_licenses | 1 | 0 | 0 | 100%
lice2/api/api.py | Lice.get_languages | 1 | 0 | 0 | 100%
lice2/api/api.py | Lice.get_license | 11 | 0 | 0 | 100%
lice2/api/api.py | Lice.get_header | 11 | 0 | 0 | 100%
lice2/api/api.py | (no function) | 10 | 0 | 0 | 100%
lice2/api/exceptions.py | LicenseNotFoundError.__init__ | 2 | 0 | 0 | 100%
lice2/api/exceptions.py | LanguageNotFoundError.__init__ | 2 | 0 | 0 | 100%
lice2/api/exceptions.py | HeaderNotFoundError.__init__ | 2 | 0 | 0 | 100%
lice2/api/exceptions.py | InvalidYearError.__init__ | 2 | 0 | 0 | 100%
lice2/api/exceptions.py | (no function) | 10 | 0 | 0 | 100%
lice2/config.py | check_default_license | 8 | 0 | 0 | 100%
lice2/config.py | (no function) | 11 | 0 | 0 | 100%
lice2/constants.py | get_available_licenses | 9 | 0 | 0 | 100%
lice2/constants.py | (no function) | 6 | 0 | 0 | 100%
lice2/core.py | main | 30 | 0 | 0 | 100%
lice2/core.py | (no function) | 16 | 0 | 1 | 100%
lice2/helpers.py | clean_path | 2 | 0 | 0 | 100%
lice2/helpers.py | guess_organization | 8 | 0 | 0 | 100%
lice2/helpers.py | get_context | 1 | 0 | 0 | 100%
lice2/helpers.py | get_lang | 5 | 0 | 0 | 100%
lice2/helpers.py | list_licenses | 10 | 0 | 0 | 100%
lice2/helpers.py | list_languages | 6 | 0 | 0 | 100%
lice2/helpers.py | load_file_template | 8 | 0 | 0 | 100%
lice2/helpers.py | get_template_content | 4 | 0 | 0 | 100%
lice2/helpers.py | load_package_template | 3 | 0 | 0 | 100%
lice2/helpers.py | extract_vars | 4 | 0 | 0 | 100%
lice2/helpers.py | generate_license | 10 | 0 | 0 | 100%
lice2/helpers.py | get_comments | 8 | 0 | 0 | 100%
lice2/helpers.py | format_license | 12 | 0 | 0 | 100%
lice2/helpers.py | get_suffix | 6 | 0 | 0 | 100%
lice2/helpers.py | list_vars | 13 | 0 | 0 | 100%
lice2/helpers.py | generate_header | 21 | 0 | 0 | 100%
lice2/helpers.py | validate_year | 4 | 0 | 0 | 100%
lice2/helpers.py | validate_license | 4 | 0 | 0 | 100%
lice2/helpers.py | copy_to_clipboard | 7 | 0 | 0 | 100%
lice2/helpers.py | get_metadata | 7 | 0 | 0 | 100%
lice2/helpers.py | get_local_year | 1 | 0 | 0 | 100%
lice2/helpers.py | (no function) | 40 | 0 | 0 | 100%
lice2/templates/__init__.py | (no function) | 0 | 0 | 0 | 100%
Total |  | 330 | 0 | 1 | 100%

No items found using the specified filter.